public with sharing class TestRetrievingDocuments {
    
    public void testRetrievingDocuments(){
    	ESignLiveSDK sdk = new ESignLiveSDK();
    	Folder folder = [select id from Folder where name='onespan' LIMIT 1]; 
    	String packageId = 'NU1klEhxdLOm4FVPf-WFfh1a9_I=';
    	String documentId = 'document1';
    	List<Document> docs = new List<Document>();
    	
    	
    	//download signed document
    	Blob signedDocument = sdk.downloadDocument(packageId, documentId);
        Document doc1 = new Document();
        doc1.Body = signedDocument;
        doc1.FolderId = folder.id;
        doc1.Name = 'test retrieving document - sigend document';
        doc1.Type = 'pdf';
    	docs.add(doc1);
    	
    	
    	//download original document
    	Blob originalDocument = downloadOriginalDocument(packageId, documentId);
        Document doc2 = new Document();
        doc2.Body = originalDocument;
        doc2.FolderId = folder.id;
        doc2.Name = 'test retrieving document - original document';
        doc2.Type = 'pdf';
    	docs.add(doc2);
    	
    	
    	//download zipped document
    	Blob zippedDocuments = downloadZippedDocuments(packageId);
        Document doc3 = new Document();
        doc3.Body = zippedDocuments;
        doc3.FolderId = folder.id;
        doc3.Name = 'test retrieving document - zipped documents';
        doc3.Type = 'zip';
    	docs.add(doc3);

    	
    	//download evidence summary
    	String auditString= sdk.getAudit(packageId);
        Document doc4 = new Document();
        doc4.Body = EncodingUtil.base64Decode(auditString);
        doc4.FolderId = folder.id;
        doc4.Name = 'test retrieving document - evidence summary';
        doc4.Type = 'pdf';
    	docs.add(doc4);

		for(Document doc: docs){
			insert doc;
		}

    
    
    }
    
    
    
    public Blob downloadOriginalDocument(String packageId, String documentId){
    	// Send Request
        String resourceUrl = '/packages/' + packageId + '/documents/' + documentId + '/original';
        HttpResponse response = doGet(resourceUrl);

        // Check response
        Blob originalDocument;
        if(response.getStatusCode() == 200)
        {
            try
            {
                originalDocument = response.getBodyAsBlob();
            }
            catch(Exception e)
            {
                throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('Error download Original Document ' + e.getMessage());
            }
        }   
        else
        {
            throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('Error download Original Document ' + response.getStatusCode() + ' - ' + response.getStatus() + ' - ' +  response.getBody());
        }

        return originalDocument;
    }
    
    
    
    public Blob downloadZippedDocuments(String packageId){
    	// Send Request
        String resourceUrl = '/packages/' + packageId + '/documents/zip';
        HttpResponse response = doGet(resourceUrl);

        // Check response
        Blob zippedDocuments;
        if(response.getStatusCode() == 200)
        {
            try
            {
                zippedDocuments = response.getBodyAsBlob();
            }
            catch(Exception e)
            {
                throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('Error download Zipped Document ' + e.getMessage());
            }
        }   
        else
        {
            throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('Error download Zipped Document ' + response.getStatusCode() + ' - ' + response.getStatus() + ' - ' +  response.getBody());
        }

        return zippedDocuments;
    }
    
    
    private HttpResponse doGet(String resourceUrl){
        e_SignLive_Connection_Settings__c connectionSettings = e_SignLive_Connection_Settings__c.getInstance('Main');    
         // Build Request
        HttpRequest request = new HttpRequest();
        request.setEndpoint(connectionSettings.Endpoint__c + resourceUrl);
        request.setMethod('GET');
        request.setHeader('Authorization', 'Basic ' + connectionSettings.API_Key__c);
        request.setHeader('Content-type', 'application/json');

        // Send Request
        HttpResponse response = (new Http()).send(request);

        if(response != null && (response.getHeader('Content-Type')).contains('json'))
        {
            System.debug('=> Formating for JSON response');
            // Format responseBody string before returning
            String inboundResponseBody = ESignLiveJSONHelper.prepareInboundJSON(response.getBody());
            response.setBody(inboundResponseBody);
        }

        return response;
    }
    
}